@@ -20,6 +20,9 @@ AUTHFAILURE = 'AuthFailure'
 # Unauthorized operation.
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnAuthorizedOperation'
 
+# Operation failed.
+FAILEDOPERATION = 'FailedOperation'
+
 # An error occurred with the cluster resource quota limit.
 FAILEDOPERATION_CLUSTERRESOURCELIMITERROR = 'FailedOperation.ClusterResourceLimitError'
 
@@ -56,6 +59,15 @@ INTERNALERROR = 'InternalError'
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# Incorrect parameter value.
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
+# Missing parameter.
+MISSINGPARAMETER = 'MissingParameter'
+
+# The number of requests exceeds the frequency limit.
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # Resource is in use.
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -74,5 +86,11 @@ RESOURCEINSUFFICIENT_SUBNET = 'ResourceInsufficient.Subnet'
 # The resource does not exist.
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# Unauthorized operation.
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
+# Unknown parameter error.
+UNKNOWNPARAMETER = 'UnknownParameter'
+
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
