@@ -39,7 +39,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AnalyzeFace", params)
+            headers = request.headers
+            body = self.call("AnalyzeFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AnalyzeFaceResponse()
@@ -72,7 +73,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CompareFace", params)
+            headers = request.headers
+            body = self.call("CompareFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CompareFaceResponse()
@@ -102,7 +104,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CopyPerson", params)
+            headers = request.headers
+            body = self.call("CopyPerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CopyPersonResponse()
@@ -133,7 +136,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFace", params)
+            headers = request.headers
+            body = self.call("CreateFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateFaceResponse()
@@ -166,7 +170,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateGroup", params)
+            headers = request.headers
+            body = self.call("CreateGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateGroupResponse()
@@ -197,7 +202,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePerson", params)
+            headers = request.headers
+            body = self.call("CreatePerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePersonResponse()
@@ -225,7 +231,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteFace", params)
+            headers = request.headers
+            body = self.call("DeleteFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteFaceResponse()
@@ -253,7 +260,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteGroup", params)
+            headers = request.headers
+            body = self.call("DeleteGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteGroupResponse()
@@ -281,7 +289,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePerson", params)
+            headers = request.headers
+            body = self.call("DeletePerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePersonResponse()
@@ -309,7 +318,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePersonFromGroup", params)
+            headers = request.headers
+            body = self.call("DeletePersonFromGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePersonFromGroupResponse()
@@ -352,7 +362,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetectFace", params)
+            headers = request.headers
+            body = self.call("DetectFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetectFaceResponse()
@@ -400,7 +411,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetectFaceAttributes", params)
+            headers = request.headers
+            body = self.call("DetectFaceAttributes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetectFaceAttributesResponse()
@@ -439,7 +451,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetectLiveFace", params)
+            headers = request.headers
+            body = self.call("DetectLiveFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetectLiveFaceResponse()
@@ -467,7 +480,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetGroupInfo", params)
+            headers = request.headers
+            body = self.call("GetGroupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetGroupInfoResponse()
@@ -495,7 +509,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetGroupList", params)
+            headers = request.headers
+            body = self.call("GetGroupList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetGroupListResponse()
@@ -523,7 +538,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetPersonBaseInfo", params)
+            headers = request.headers
+            body = self.call("GetPersonBaseInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetPersonBaseInfoResponse()
@@ -551,7 +567,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetPersonGroupInfo", params)
+            headers = request.headers
+            body = self.call("GetPersonGroupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetPersonGroupInfoResponse()
@@ -579,7 +596,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetPersonList", params)
+            headers = request.headers
+            body = self.call("GetPersonList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetPersonListResponse()
@@ -607,7 +625,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetPersonListNum", params)
+            headers = request.headers
+            body = self.call("GetPersonListNum", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetPersonListNumResponse()
@@ -635,7 +654,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyGroup", params)
+            headers = request.headers
+            body = self.call("ModifyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyGroupResponse()
@@ -663,7 +683,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPersonBaseInfo", params)
+            headers = request.headers
+            body = self.call("ModifyPersonBaseInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPersonBaseInfoResponse()
@@ -691,7 +712,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPersonGroupInfo", params)
+            headers = request.headers
+            body = self.call("ModifyPersonGroupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPersonGroupInfoResponse()
@@ -734,7 +756,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SearchFaces", params)
+            headers = request.headers
+            body = self.call("SearchFaces", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SearchFacesResponse()
@@ -776,7 +799,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SearchFacesReturnsByGroup", params)
+            headers = request.headers
+            body = self.call("SearchFacesReturnsByGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SearchFacesReturnsByGroupResponse()
@@ -814,7 +838,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SearchPersons", params)
+            headers = request.headers
+            body = self.call("SearchPersons", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SearchPersonsResponse()
@@ -851,7 +876,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SearchPersonsReturnsByGroup", params)
+            headers = request.headers
+            body = self.call("SearchPersonsReturnsByGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SearchPersonsReturnsByGroupResponse()
@@ -886,7 +912,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("VerifyFace", params)
+            headers = request.headers
+            body = self.call("VerifyFace", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.VerifyFaceResponse()
@@ -922,7 +949,8 @@ class IaiClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("VerifyPerson", params)
+            headers = request.headers
+            body = self.call("VerifyPerson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.VerifyPersonResponse()
