@@ -26,34 +26,6 @@ class TemClient(AbstractClient):
     _service = 'tem'
 
 
-    def CreateApplication(self, request):
-        """This API is used to create an application.
-
-        :param request: Request instance for CreateApplication.
-        :type request: :class:`tencentcloud.tem.v20210701.models.CreateApplicationRequest`
-        :rtype: :class:`tencentcloud.tem.v20210701.models.CreateApplicationResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateApplication", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateApplicationResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateCosToken(self, request):
         """This API is used to generate a COS temporary key.
 
@@ -64,7 +36,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCosToken", params)
+            headers = request.headers
+            body = self.call("CreateCosToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCosTokenResponse()
@@ -92,7 +65,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEnvironment", params)
+            headers = request.headers
+            body = self.call("CreateEnvironment", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEnvironmentResponse()
@@ -120,7 +94,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateResource", params)
+            headers = request.headers
+            body = self.call("CreateResource", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateResourceResponse()
@@ -138,37 +113,6 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DeleteApplication(self, request):
-        """This API is used to delete an application.
-          - Stop the application if it’s running
-          - Delete resources associated with this application
-          - Delele the application
-
-        :param request: Request instance for DeleteApplication.
-        :type request: :class:`tencentcloud.tem.v20210701.models.DeleteApplicationRequest`
-        :rtype: :class:`tencentcloud.tem.v20210701.models.DeleteApplicationResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DeleteApplication", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteApplicationResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DeleteIngress(self, request):
         """This API is used to delete an ingress rule.
 
@@ -179,7 +123,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteIngress", params)
+            headers = request.headers
+            body = self.call("DeleteIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteIngressResponse()
@@ -207,7 +152,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeployApplication", params)
+            headers = request.headers
+            body = self.call("DeployApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeployApplicationResponse()
@@ -235,7 +181,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeApplicationPods", params)
+            headers = request.headers
+            body = self.call("DescribeApplicationPods", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeApplicationPodsResponse()
@@ -263,7 +210,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEnvironments", params)
+            headers = request.headers
+            body = self.call("DescribeEnvironments", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEnvironmentsResponse()
@@ -291,7 +239,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIngress", params)
+            headers = request.headers
+            body = self.call("DescribeIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIngressResponse()
@@ -319,7 +268,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIngresses", params)
+            headers = request.headers
+            body = self.call("DescribeIngresses", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIngressesResponse()
@@ -347,7 +297,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRelatedIngresses", params)
+            headers = request.headers
+            body = self.call("DescribeRelatedIngresses", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRelatedIngressesResponse()
@@ -375,7 +326,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GenerateApplicationPackageDownloadUrl", params)
+            headers = request.headers
+            body = self.call("GenerateApplicationPackageDownloadUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GenerateApplicationPackageDownloadUrlResponse()
@@ -403,7 +355,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyApplicationInfo", params)
+            headers = request.headers
+            body = self.call("ModifyApplicationInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyApplicationInfoResponse()
@@ -431,7 +384,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyEnvironment", params)
+            headers = request.headers
+            body = self.call("ModifyEnvironment", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyEnvironmentResponse()
@@ -459,7 +413,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyIngress", params)
+            headers = request.headers
+            body = self.call("ModifyIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyIngressResponse()
@@ -487,7 +442,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartApplication", params)
+            headers = request.headers
+            body = self.call("RestartApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartApplicationResponse()
@@ -515,7 +471,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartApplicationPod", params)
+            headers = request.headers
+            body = self.call("RestartApplicationPod", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartApplicationPodResponse()
@@ -543,7 +500,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RollingUpdateApplicationByVersion", params)
+            headers = request.headers
+            body = self.call("RollingUpdateApplicationByVersion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RollingUpdateApplicationByVersionResponse()
@@ -571,7 +529,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopApplication", params)
+            headers = request.headers
+            body = self.call("StopApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopApplicationResponse()
